/*

High tau group
Cutoff Data (Table5 and 6)

*/

* Argument `1' = Master Dataset
if ("`1'"==""){
	local dataset Dataset_for_DesStat
}
else{
	local dataset `1'
}

* Argument `2' = Using Dataset
if ("`2'"==""){
	local using Dataset_xlearn
}
else{
	local using `2'
}


cap cwf default
use `dataset', clear

merge 1:1 id fy using `using'

/* Difine the upper and lower 10th percentile*/
centile tau, c(10 90)
local lb = r(c_1)
local ub = r(c_2)
gen     high_tau = 0 if tau <= `lb' & !missing(tau) // less than lower 10th percentile
replace high_tau = 1 if tau >= `ub' & !missing(tau) // more than upper 10th percentile
label define tau_cat 0 "low tau" 1 "high tau"
label values high_tau tau_cat


/* comment out by reviewer's comment
gen high_tau = (tau >= 0.25) if !missing(tau)
label define high_tau 0 "low tau" 1 "high tau"
label values high_tau high_tau
*/

cap mkdir Table

* Making Table 5 and 6
table1, by(high_tau) vars(sex cat \ age contn %2.1f \ clin_grp cat /// 個人背景 // Personal Characteristics
	\ smk cat \ smk_int contn %2.1f \ smk_year contn %2.1f /// 喫煙 // Smoking status
	\ sbp contn %2.1f \ dbp contn %2.1f /// 血圧 // Blood pressure
	\ bmi contn %2.1f \ abdc contn %2.1f /// 測定 // Measurement
	\ vis_rt_bin bin \ vis_lt_bin bin /// 視力 0.6未満 // vision lower than 0.6
	\ hear_1k_rt bin \ hear_1k_lt bin \ hear_4k_rt bin \ hear_4k_lt bin /// 聴力 // Hearing test
	 \ phyexam bin \ ecg bin \ chest bin /// 理学所見 // Physical examination
	\ urin_bld cat \ urin_pro cat \ urin_sug cat /// 尿検査 // Urinalysis
	\ hgb contn %2.1f \ rbc contn %2.1f /// 貧血検査 // Anemia
	\ ast contn %2.1f \ alt contn %2.1f \ gtp contn %2.1f /// 肝機能 // Liver enzyme
	\ ldl_c contn %2.1f \ hdl_c contn %2.1f \ ftg contn %2.1f \ ctg contn %2.1f /// 脂質 // Blood lipid
	\ hba1c contn %2.1f \ fbs contn %2.1f \ cbs contn %2.1f /// 血糖 // blood sugar
	\ pres_bs bin \ pres_tg bin \ pres_bp bin /// 治療歴 // history of medical treatment
	\ outcome bin) ///
	plusminus /*cmis*/ saving(./Table/Result_Table5_and_6`3'.xls, replace)
	
* Std diff
stddiff ///
	i.sex age i.clin_grp /// 個人背景 // Personal Characteristics
	i.smk smk_int smk_year /// 喫煙 // Smoking status
	sbp dbp /// 血圧 // Blood pressure
	bmi abdc /// 測定 // Measurement
	i.vis_rt_bin i.vis_lt_bin /// 視力 0.6未満 // vision lower than 0.6
	i.hear_1k_rt i.hear_1k_lt i.hear_4k_rt i.hear_4k_lt /// 聴力 // Hearing test
	i.phyexam i.ecg i.chest /// 理学所見 // Physical examination
	i.urin_bld i.urin_pro i.urin_sug /// 尿検査 // Urinalysis
	hgb rbc /// 貧血検査 // Anemia
	ast alt gtp /// 肝機能 // Liver enzyme
	ldl_c hdl_c ftg ctg /// 脂質 // Blood lipid
	hba1c fbs cbs /// 血糖 // blood sugar
	i.pres_bs i.pres_tg i.pres_bp /// 治療歴 // history of medical treatment
	i.outcome, by(high_tau) abs