/*

Calculation CI (Table3)
Purpose of this do file:
 In this do file, the confidence intervals for CATE are calculated using bootstrapping.

*/


// The user-driven command "fframeappend" is required.
// If you have not installed it, you will need to execute the following command.

// ssc install fframeappend


/***** ***** ***** ***** ***** ***** ***** ***** ***** ***** 
*
* Define program "xlearn_bs" for calculating 95%CI
*
***** ***** ***** ***** ***** ***** ***** ***** ***** ****/

capture program drop xlearn_bs
program define xlearn_bs, rclass

	/***** ***** ***** ***** ***** ***** ***** ***** ***** ***** 
	*
	* Data Load for bootstrapping
	*
	***** ***** ***** ***** ***** ***** ***** ***** ***** ****/
	use $dataset, clear
	
	display "preserve"
	preserve
	
	capture cwf default
	capture frame drop df_0
	capture frame drop df_1
	capture frame drop df_bs

	/***** ***** ***** ***** ***** ***** ***** ***** ***** ***** 
	*
	* Bootstrap resampling: 
	*     resampling in each of the non-exposed/exposed groups
	*
	***** ***** ***** ***** ***** ***** ***** ***** ***** ****/
	
	forvalues E=0/1 {
		frame copy default df_`E'
		cwf df_`E'
		drop if fy_bin == `E'
		bsample

		cwf default
	}

	frame copy df_0 df_bs
	cwf df_bs
	fframeappend, using(df_1)

	/***** ***** ***** ***** ***** ***** ***** ***** ***** ***** 
	*
	* X-learner:
	*     do "X-learner" that optimized for this study
	*
	***** ***** ***** ***** ***** ***** ***** ***** ***** ****/
	// qui cap xlearner
	qui cap xlearner
	local rc = _rc
	display "rc = `rc'" // for test
	
	///// Result: Evaluation of Base learners /////
	// for test
	/* display $AUC_M0
	display $AUC_M1
	display $RMSE_M2
	display $RMSE_M3 */
	
	// If the performance of the base learners is poor, the replication is skipped.
	if ($AUC_M0 < 0.945 | $AUC_M1 < 0.885 | $RMSE_M2 > 0.115 | $RMSE_M3 > 0.16){
		local rc = 403
	}
	///// Base learners performance criteria and Percentage of criteria met /////
	// 0.88 , 0.88 , 0.175, 0.175  -> 30.3%　(Insufficient performance)
	// 0.905, 0.88 , 0.15 , 0.17   -> 25.0% (Insufficient performance)
	// 0.925, 0.88 , 0.125, 0.165  -> 16.5% (Somewhat Insufficient performance)
	// 0.945, 0.885, 0.115, 0.16   ->  8.3% (This criterion was adopted)
	
	/***** ***** ***** ***** ***** ***** ***** ***** ***** ***** 
	*
	* Calculate CATE(x)
	*     (1) total cohort
	*     (2) stratified by devisions
	*     (3) stratified by sex
	*
	***** ***** ***** ***** ***** ***** ***** ***** ***** ****/
	
	display "rc = `rc'"
	if ("`rc'"=="403"){
		// display "`rc', null route" // for test
	}
	else if ("`rc'"=="0") {
		// display "`rc', not null route" // for test
		su tau 
		return scalar boot = r(mean)
		// di "forvalues" // for test
		forvalues x=0/3 {
			su tau if clin_grp==`x'
			return scalar boot_`x' = r(mean)
		}
		
		su tau if sex==0
		return scalar boot_f = r(mean)
		
		su tau if sex==1
		return scalar boot_m = r(mean)
	}
	
	capture restore
end

/***** ***** ***** ***** ***** ***** ***** ***** ***** ***** 
*
* Define local and global macros
*
***** ***** ***** ***** ***** ***** ***** ***** ***** ****/

if ("`1'"==""){
	local dataset Dataset_bs
}
else{
	global dataset `1'
}

if ("`3'"==""){
	local rep=1000
}
else{
	local rep=`3'
}

/***** ***** ***** ***** ***** ***** ***** ***** ***** ***** 
*
* Calculate the point estimates of CATE
*
***** ***** ***** ***** ***** ***** ***** ***** ***** ****/

use $dataset, clear

qui xlearner

su tau
matrix input observe = (-1, `r(mean)')


forvalues g = 0/3 {
	summarize tau if clin_grp == `g'
	matrix observe = (observe \ `g',`r(mean)')
}

su tau if sex==0
matrix observe = (observe \ 4, `r(mean)')

su tau if sex==1
matrix observe = (observe \ 5, `r(mean)')

mat rowname observe = zentai jimu kenkyu iryou syutyu female male
mat colname observe = category tau(x)

// mat list observe // for test

/***** ***** ***** ***** ***** ***** ***** ***** ***** ***** 
*
* Calculate the confidence intervals of CATE using bootstrap
*
***** ***** ***** ***** ***** ***** ***** ***** ***** ****/

capture log close 
log using "./Table/xlearn_ci_total`2'.smcl", replace
simulate zentai=r(boot) ///
	jimu=r(boot_0) kenkyu = r(boot_1) iryou = r(boot_2) syutyu = r(boot_3) ///
	female=r(boot_f) male=r(boot_m) , reps(`rep') seed(12345): xlearn_bs

* Create point estimates format as a vector (i.e., a 1-by-N matrix)
matrix pe = observe[1..., 2]'
// matrix list pe // for test

* Calculate bootstrap SE and confidence intervals with the "bstat" command
save Dataset_`2', 
keep if zentai != .
keep in 1/1000
bstat, stat(pe) n(3572)

log close




