
capture program drop xlearn_bs2
program define xlearn_bs2, rclass
	use Dataset_xlearn_anonym, clear
	preserve


	bsample _N, strata(fy_bin)

	su tau 
	return scalar boot = r(mean)
	di "forvalues"
	forvalues x=0/3 {
		su tau if clin_grp==`x'
		return scalar boot_`x' = r(mean)
	}
	
	su tau if sex==0
	return scalar boot_f = r(mean)
	
	su tau if sex==1
	return scalar boot_m = r(mean)

	
	capture restore
end

/***** ***** ***** ***** ***** ***** ***** ***** ***** ***** 
*
* Define local and global macros
*
***** ***** ***** ***** ***** ***** ***** ***** ***** ****/

if ("`1'"==""){
	local dataset Dataset_bs
}
else{
	global dataset `1'
}

if ("`3'"==""){
	local rep=1000
}
else{
	local rep=`3'
}

/***** ***** ***** ***** ***** ***** ***** ***** ***** ***** 
*
* Calculate the point estimates of CATE
*
***** ***** ***** ***** ***** ***** ***** ***** ***** ****/

use Dataset_anonym, clear
qui xlearner

su tau
matrix input observe = (-1, `r(mean)')


forvalues g = 0/3 {
	summarize tau if clin_grp == `g'
	matrix observe = (observe \ `g',`r(mean)')
}

su tau if sex==0
matrix observe = (observe \ 4, `r(mean)')

su tau if sex==1
matrix observe = (observe \ 5, `r(mean)')


mat rowname observe = zentai jimu kenkyu iryou syutyu female male
mat colname observe = category tau(x)

mat list observe

/***** ***** ***** ***** ***** ***** ***** ***** ***** ***** 
*
* Calculate the confidence intervals of CATE using bootstrap
*
***** ***** ***** ***** ***** ***** ***** ***** ***** ****/

capture log close 
log using "./Table/xlearn_ci2_total`2'.smcl", replace
simulate zentai=r(boot) ///
	jimu=r(boot_0) kenkyu = r(boot_1) iryou = r(boot_2) syutyu = r(boot_3) ///
	female=r(boot_f) male=r(boot_m) , reps(`rep') seed(12345): xlearn_bs2

* Create point estimates format as a vector (i.e., a 1-by-N matrix)
matrix pe = observe[1..., 2]'
matrix list pe

* Calculate bootstrap SE and confidence intervals with the "bstat" command
bstat, stat(pe) n(3572)

log close
