

/**** ***** ***** ***** ***** ***** ***** ***** ***** *****

Stata do-file for ...

Study Title:
Heterogeneity of the Effect of the COVID-19 Pandemic 
on the Incidence of Metabolic Syndrome Onset in Japan

Author:
Toshiharu Mitsuhashi
Center for Innovative Clinical Medicine, Okayama University Hospital

Purpose of this do file:
This is the MASTER to run all do files for analysis.

***** ***** ***** ***** ***** ***** ***** ***** ***** ****/

**Caustion** 
// Data cleaning before anonymous processing is omitted 
// for the sake of protecting personal information.

version 17
cls

* 0. Install user-driven commands if not installed
ssc install table1      , replace
ssc install schemepack  , replace
ssc install fframeappend, replace

* 1. Anonymize the original dataset.
// do crDataset_anonym

**Note**
// Note that "crDataset_anonym" is not executable because it refers to 
// the data file before anonymization, and the random seed for anonymization 
// is masked. It is described here for the purpose of illustrating 
// the process of removing quasi-identifiers.

* 2.Make Descriptive Stat Table (Table1 and 2)
do anDesStat Dataset_anonym _anonym

* 3. Make X-learned Dataset (Table3 and 4)
do anX_learner02 Dataset_anonym _anonym

* 4. Calculation CI (Table3 and 4)
// do anX_learn_bs_total Dataset_anonym _anonym_15k 15000
do anX_learn_bs_total_diff Dataset_anonym _anonym_diff_15k 15000

**Note**
// This process 4 is very time consuming.
// It took approximately [8 HOURS] to complete in the following environment.
// Stata 17/MP8, Windows 11 Home
// CPU: 11th Gen Intel(R) Core(TM) i9-11900K @ 3.50GHz 3.50 GHz
// RAM: 64.0 GB
// Graphic NVIDIA GeForce RTX 3070 Ti

**Note**
// "anX_learn_bs_total_diff" is new version of "anX_learn_bs_total".

* 5. Draw Graphs (Figure3 and 4)
do anMakeGraph_scatter_tau_age Dataset_xlearn_anonym _anonym

* 6. Cutoff Data (Table5 and 6)
do anHigh_tau_what_person Dataset_anonym Dataset_xlearn_anonym _anonym
